@@ -17,14 +17,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.11 2000/04/14 11:18:48 fredgo Exp $
+# $Id: Base.py,v 1.11.2.2 2000/10/17 10:40:46 fredgo Exp $
 
 from string import *
 import re, copy, os
 import Pyblio.Help
 from types import *
 
-from Pyblio import Config, Open, Utils, Key, Iterator, Selection
+from Pyblio import Config, Open, Utils, Key, Iterator, Selection, Autoload
 
 import gettext
 _ = gettext.gettext
@@ -183,7 +183,9 @@ class DataBase:
 	''' Adds an (eventually) anonymous entry '''
 
         if entry.key is None:
-            entry.key = Utils.generate_key (entry, self)
+            # call a key generator
+            keytype   = Config.get ('base/keyformat').data
+            entry.key = Autoload.get_by_name ('key', keytype).data (entry, self)
         else:
             entry.key.base = self.key
             
