@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: __init__.py,v 1.1.1.1.2.1 2000/07/27 08:43:35 fredgo Exp $
+# $Id: __init__.py,v 1.1.1.1.2.2 2000/08/03 11:46:32 fredgo Exp $
 
 # Perform the first initialisation of Gnome, so that the options passed to the script
 # are not passed to Gnome
@@ -26,9 +26,19 @@ import sys
 
 sys.argv = sys.argv [:2] + ['--'] + sys.argv [2:]
 
+# correctly identify the program
+import gnome
+from Pyblio import version
+
+gnome.app_id      = 'Pybliographic'
+gnome.app_version = version.version
+
+# import the GUI
 import gnome.ui
 
+# clean up our garbage
 sys.argv = sys.argv [:2] + sys.argv [3:]
 
+del sys, gnome
 
 
