@@ -19,16 +19,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybconvert.py,v 1.2 2000/03/24 10:13:22 fredgo Exp $
+# $Id: pybconvert.py,v 1.2.2.1 2000/05/29 14:15:25 fredgo Exp $
 
-import os, sys, string
+import os, sys, string, gettext
 
-if len (sys.argv) < 3 or len (sys.argv) > 4:
+_ = gettext.gettext
+
+if len (sys.argv) < 4 or len (sys.argv) > 5:
     print _("usage: pybconvert <source>..<target> <input> [output]")
     sys.exit (1)
 
 
-format = sys.argv [1]
+format = sys.argv [2]
 
 try:
     source, target = string.split (format, '..')
@@ -39,13 +41,13 @@ except:
 
 from Pyblio import Open
 
-f_in = sys.argv [2]
+f_in = sys.argv [3]
 
-if len (sys.argv) == 3:
+if len (sys.argv) == 4:
     f_out = sys.stdout
 else:
-    f_out = open (sys.argv [3], 'w')
+    f_out = open (sys.argv [4], 'w')
 
 database = Open.bibopen (f_in, source)
-Open.bibwrite (database, how = target, out = f_out)
+Open.bibwrite (database.iterator (), how = target, out = f_out)
     
